Package: quantro
Title: A test for when to use quantile normalization
Version: 1.44.0
Authors@R: c(
    person("Stephanie", "Hicks", role = c("aut", "cre"), 
            email = "shicks19@jhu.edu", 
            comment = c(ORCID = "0000-0002-7858-0231")),
    person("Rafael", "Irizarry", role = "aut", 
            comment = c(ORCID = "0000-0002-3944-4309")))
Imports: Biobase, minfi, doParallel, foreach, iterators, ggplot2,
        methods, RColorBrewer
Depends: R (>= 4.0)
Suggests: rmarkdown, knitr, RUnit, BiocGenerics, BiocStyle
VignetteBuilder: knitr
RoxygenNote: 6.0.1
Encoding: UTF-8
Description: A data-driven test for the assumptions of
    quantile normalization using raw data such as objects
    that inherit eSets (e.g. ExpressionSet, MethylSet).
    Group level information about each sample (such as
    Tumor / Normal status) must also be provided because
    the test assesses if there are global differences in
    the distributions between the user-defined groups.
License: GPL-3
biocViews: Normalization, Preprocessing, MultipleComparison,
        Microarray, Sequencing
git_url: https://git.bioconductor.org/packages/quantro
git_branch: RELEASE_3_22
git_last_commit: d148fc5
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 05:54:55 UTC; biocbuild
Author: Stephanie Hicks [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7858-0231>),
  Rafael Irizarry [aut] (ORCID: <https://orcid.org/0000-0002-3944-4309>)
Maintainer: Stephanie Hicks <shicks19@jhu.edu>
