# Generated by roxygen2: do not edit by hand

export(MSbetween)
export(MSwithin)
export(anova)
export(matboxplot)
export(matdensity)
export(quantro)
export(quantroPlot)
export(quantroPvalPerm)
export(quantroStat)
export(quantroStatPerm)
export(summary)
exportClasses(quantro)
exportMethods(MSbetween)
exportMethods(MSwithin)
exportMethods(anova)
exportMethods(quantroPvalPerm)
exportMethods(quantroStat)
exportMethods(quantroStatPerm)
exportMethods(summary)
import(Biobase)
import(RColorBrewer)
import(doParallel)
import(foreach)
import(ggplot2)
import(iterators)
import(minfi)
importFrom(methods,show)
