#' @name flowSorted
#' @title A subset of FlowSorted.DLPFC.450k data set
#'
#' @description 
#' This is the script used to create a subset of the 
#' FlowSorted.DLPFC.450k data set from Bioconductor. 
#' The purpose is to create an example object for the man
#' pages and vignette in this package. 
#' 
#' The object was created using the script in /inst and
#' located in the /data folder. 
#' 
#' @docType data
#' @format A MethylSet object with 1e4 rows (probes) 
#' and 58 columns (samples).
#' 
#' @rdname flowSorted
#' 
NULL