% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllClasses.R
\docType{class}
\name{quantro-class}
\alias{quantro-class}
\title{quantro}
\description{
This is the S4 class quantro container
}
