% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllGenerics.R, R/methods.R
\docType{methods}
\name{quantroStat}
\alias{quantroStat}
\alias{quantroStat.quantro}
\alias{quantroStat,quantro-method}
\title{Accessors for the 'quantroStat' slot of a quantro object.}
\usage{
quantroStat(object)

\S4method{quantroStat}{quantro}(object)

\S4method{quantroStat}{quantro}(object)
}
\arguments{
\item{object}{a \code{quantro} object}
}
\description{
Accessors for the 'quantroStat' slot of a quantro object.
}
\examples{
library(minfi)
data(flowSorted)
pd <- pData(flowSorted)
qtest <- quantro(flowSorted, groupFactor = pd$CellType)
quantroStat(qtest)
}
