% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllGenerics.R, R/methods.R
\docType{methods}
\name{MSbetween}
\alias{MSbetween}
\alias{MSbetween.quantro}
\alias{MSbetween,quantro-method}
\title{Accessors for the 'MSbetween' slot of a quantro object.}
\usage{
MSbetween(object)

\S4method{MSbetween}{quantro}(object)

\S4method{MSbetween}{quantro}(object)
}
\arguments{
\item{object}{a \code{quantro} object}
}
\description{
Accessors for the 'MSbetween' slot of a quantro object.
}
\examples{
library(minfi)
data(flowSorted)
pd <- pData(flowSorted)
qtest <- quantro(flowSorted, groupFactor = pd$CellType)
MSbetween(qtest)
}
